@@ -4,11 +4,6 @@
 
 #include <khtml_part.h>
 
-#include "glossary.h"
-#include "navigator.h"
-
-#include <QEvent>
-
 class KActionCollection;
 
 namespace DOM {
@@ -18,7 +13,7 @@ namespace DOM {
 
 namespace KHC {
 
-class Formatter;
+class GrantleeFormatter;
 
 class View : public KHTMLPart
 {
@@ -50,7 +45,7 @@ class View : public KHTMLPart
 
     int fontScaleStepping() const { return m_fontScaleStepping; }
 
-    Formatter *formatter() const { return mFormatter; }
+    GrantleeFormatter *grantleeFormatter() const { return mGrantleeFormatter; }
 
     void copySelectedText();
 
@@ -84,7 +79,7 @@ class View : public KHTMLPart
 
     int m_fontScaleStepping;
 
-    Formatter *mFormatter;
+    GrantleeFormatter *mGrantleeFormatter;
     KActionCollection *mActionCollection;
     QString mCopyURL;
 };
